Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func MainOptions ¶
func MainOptions(options *Options)
MainOptions runs the judge with the given options
Types ¶
type OptionalFile ¶
OptionalFile specifies the name of an optional file and the fallback file if the file is not found
type Options ¶
type Options struct {
Chdir string
ExcludeCases []string // exclude these cases
IncludeCases []string // include these cases
AsUser string // run the judge as this user. privileged.
RuleFile string // use the rules defined in the config file instead of argv[0]. privileged.
Server string // the judge server
Homework string // the name of the homework
Bin string // skip compiling and use the given binary. privileged.
MedianOf int // run each case multiple times and pick the median as the result
Debug bool // output debug messages
}
Options is passed to MainOptions
Click to show internal directories.
Click to hide internal directories.